@@ -615,13 +615,11 @@ static void Oops_set_regs(const char *line, const char *p,
 		reg = 0;
 	    }
 	    reg = Oops_truncate_address(reg, options);
-	    if (reg > 1024) {
-		strcpy(regname, ">>");
-		strncpy(regname+2, string[1], sizeof(regname)-2);
-		if (strlen(regname) < sizeof(regname)-1)
-		    strcat(regname, ";");
-		add_symbol_n(ss, reg, 'R', 1, regname);
-	    }
+	    strcpy(regname, ">>");
+	    strncpy(regname+2, string[1], sizeof(regname)-2);
+	    if (strlen(regname) < sizeof(regname)-1)
+		strcat(regname, ";");
+	    add_symbol_n(ss, reg, 'R', 1, regname);
 	    p += re_Oops_regs_pmatch[0].rm_eo;
 	}
 	else
@@ -1128,12 +1126,12 @@ static void Oops_mips_regs(const char *line, SYMBOL_SET *ss, const OPTIONS *opti
 		break;
 	    }
 	    reg = Oops_truncate_address(reg, options);
-	    if (reg > 1024) {
-		snprintf(regname, sizeof(regname), ">>$%d;", reg_num);
-		add_symbol_n(ss, reg, 'R', 1, regname);
-	    }
+	    snprintf(regname, sizeof(regname), ">>$%d;", reg_num);
+	    add_symbol_n(ss, reg, 'R', 1, regname);
 	    p += re_unbracketed_address_pmatch[0].rm_eo;
 	    ++reg_num;
+	    if (reg_num == 26)
+		reg_num += 2;			/* skip k0, k1 */
 	}
 	else
 	    break;
@@ -1335,10 +1333,8 @@ static void Oops_ppc_regs(const char *line, SYMBOL_SET *ss, const OPTIONS *optio
 		break;
 	    }
 	    reg = Oops_truncate_address(reg, options);
-	    if (reg > 1024) {
-		snprintf(regname, sizeof(regname), ">>GPR%d;", reg_num);
-		add_symbol_n(ss, reg, 'R', 1, regname);
-	    }
+	    snprintf(regname, sizeof(regname), ">>GPR%d;", reg_num);
+	    add_symbol_n(ss, reg, 'R', 1, regname);
 	    p += re_unbracketed_address_pmatch[0].rm_eo;
 	    ++reg_num;
 	}
@@ -1374,7 +1370,7 @@ static const char *Oops_trace(const char *line)
      */
     RE_COMPILE(&re_Oops_trace,
 	    "^("						     /* 1 */
-		    "(Call Trace: )"				     /* 2 */
+		    "(Call Trace: *)"				     /* 2 */
     /* alpha */     "|(Trace:)"					     /* 3 */
     /* various */   "|(" BRACKETED_ADDRESS ")"			     /* 4,5 */
     /* ppc */	    "|(Call backtrace:)"			     /* 6 */
@@ -1625,11 +1621,9 @@ static void Oops_set_s390_regs(const char *line, const char *p,
 		reg = 0;
 	    }
 	    reg = Oops_truncate_address(reg, options);
-	    if (reg > 1024) {
-		strcpy(regname, ">>");
-		snprintf(regname, sizeof(regname), "r%-2d;  ", s390_reg_num);
-		add_symbol_n(ss, reg, 'R', 1, regname);
-	    }
+	    strcpy(regname, ">>");
+	    snprintf(regname, sizeof(regname), "r%-2d;  ", s390_reg_num);
+	    add_symbol_n(ss, reg, 'R', 1, regname);
 	    p += re_unbracketed_address_pmatch[0].rm_eo;
 	    ++s390_reg_num;
 	}
@@ -1749,7 +1743,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
      * string 2 is defined if the text is 'Stack from '.
      * string 3 is defined if the text is 'Stack: '.
      * string 4 is defined if the text might be a stack continuation.
-     * string 5 is defined if the text is 'Call Trace: '.
+     * string 5 is defined if the text is 'Call Trace: *'.
      * string 6 is defined if the text might be a trace continuation.
      * string 7 is the address part of the BRACKETED_ADDRESS.
      *
@@ -1794,7 +1788,7 @@ static int Oops_print(const char *line, const char **text, char ***string,
     /* i386 */	    "(Stack: )"				/*  2  S */
     /* m68k */	    "|(Stack from )"			/*  3  S */
     /* various */   "|([0-9a-fA-F]{4,})"		/*  4  S,T */
-    /* various */   "|(Call Trace: )"			/*  5  T */
+    /* various */   "|(Call Trace: *)"			/*  5  T */
     /* various */   "|(" BRACKETED_ADDRESS ")"		/* 6,7 T */
     /* various */   "|(Version_[0-9]+)"			/*  8 */
     /* alpha */	    "|(Trace:)"				/*  9  T */
@@ -2223,12 +2217,17 @@ static void Oops_format(const SYMBOL_SET *ss_format, OPTIONS *options)
 	    printf("%s\n", s->name);
 	}
 	else {
+	    /* Suppress registers that do not resolve to symbols */
+	    char *map = map_address(&ss_merged, s->address, options);
+	    if (s->type == 'R') {
+		if (index(map, '+') == NULL || strncmp(map, "<END_OF_CODE+", 13) == 0) {
+		    continue;
+		}
+	    }
 	    if (prev_type != s->type)
 		printf("\n");
 	    printf("%s %s %s",
-		s->name,
-		format_address(s->address, options),
-		map_address(&ss_merged, s->address, options));
+		s->name, format_address(s->address, options), map);
 	    if (s->type == 'E') {
 		eip = s->address;
 		if (eip)
