@@ -182,7 +182,7 @@ char *map_address(const SYMBOL_SET *ss, addr_t address,
     SYMBOL *s;
     static char *map = NULL;
     static int size = 0;
-    static const char procname[] = "map_address_n";
+    static const char procname[] = "map_address";
 
     address &= truncate_mask;
     DEBUG(3, "%s %s", ss->source, format_address(address, options));
